@@ -15,6 +15,7 @@ class AlipayEbppInvoiceExpensecontrolQuotaCreateModel(object):
         self._enterprise_id = None
         self._outer_source_id = None
         self._owner_id = None
+        self._owner_open_id = None
         self._owner_type = None
         self._platform = None
         self._quota_type = None
@@ -72,6 +73,13 @@ class AlipayEbppInvoiceExpensecontrolQuotaCreateModel(object):
     def owner_id(self, value):
         self._owner_id = value
     @property
+    def owner_open_id(self):
+        return self._owner_open_id
+
+    @owner_open_id.setter
+    def owner_open_id(self, value):
+        self._owner_open_id = value
+    @property
     def owner_type(self):
         return self._owner_type
 
@@ -152,6 +160,11 @@ class AlipayEbppInvoiceExpensecontrolQuotaCreateModel(object):
                 params['owner_id'] = self.owner_id.to_alipay_dict()
             else:
                 params['owner_id'] = self.owner_id
+        if self.owner_open_id:
+            if hasattr(self.owner_open_id, 'to_alipay_dict'):
+                params['owner_open_id'] = self.owner_open_id.to_alipay_dict()
+            else:
+                params['owner_open_id'] = self.owner_open_id
         if self.owner_type:
             if hasattr(self.owner_type, 'to_alipay_dict'):
                 params['owner_type'] = self.owner_type.to_alipay_dict()
@@ -203,6 +216,8 @@ class AlipayEbppInvoiceExpensecontrolQuotaCreateModel(object):
             o.outer_source_id = d['outer_source_id']
         if 'owner_id' in d:
             o.owner_id = d['owner_id']
+        if 'owner_open_id' in d:
+            o.owner_open_id = d['owner_open_id']
         if 'owner_type' in d:
             o.owner_type = d['owner_type']
         if 'platform' in d:
