@@ -12,6 +12,7 @@ class AlipayEbppInvoiceExpensecontrolQuotaQueryModel(object):
         self._agreement_no = None
         self._enterprise_id = None
         self._owner_id = None
+        self._owner_open_id = None
         self._owner_type = None
         self._page_num = None
         self._page_size = None
@@ -48,6 +49,13 @@ class AlipayEbppInvoiceExpensecontrolQuotaQueryModel(object):
     def owner_id(self, value):
         self._owner_id = value
     @property
+    def owner_open_id(self):
+        return self._owner_open_id
+
+    @owner_open_id.setter
+    def owner_open_id(self, value):
+        self._owner_open_id = value
+    @property
     def owner_type(self):
         return self._owner_type
 
@@ -116,6 +124,11 @@ class AlipayEbppInvoiceExpensecontrolQuotaQueryModel(object):
                 params['owner_id'] = self.owner_id.to_alipay_dict()
             else:
                 params['owner_id'] = self.owner_id
+        if self.owner_open_id:
+            if hasattr(self.owner_open_id, 'to_alipay_dict'):
+                params['owner_open_id'] = self.owner_open_id.to_alipay_dict()
+            else:
+                params['owner_open_id'] = self.owner_open_id
         if self.owner_type:
             if hasattr(self.owner_type, 'to_alipay_dict'):
                 params['owner_type'] = self.owner_type.to_alipay_dict()
@@ -166,6 +179,8 @@ class AlipayEbppInvoiceExpensecontrolQuotaQueryModel(object):
             o.enterprise_id = d['enterprise_id']
         if 'owner_id' in d:
             o.owner_id = d['owner_id']
+        if 'owner_open_id' in d:
+            o.owner_open_id = d['owner_open_id']
         if 'owner_type' in d:
             o.owner_type = d['owner_type']
         if 'page_num' in d:
