@@ -3,6 +3,7 @@
 import json
 
 from alipay.aop.api.constant.ParamConstants import *
+from alipay.aop.api.domain.BkAgentReqInfo import BkAgentReqInfo
 from alipay.aop.api.domain.BusinessParams import BusinessParams
 from alipay.aop.api.domain.ExtUserInfo import ExtUserInfo
 from alipay.aop.api.domain.ExtendParams import ExtendParams
@@ -18,10 +19,12 @@ class AlipayTradeCreateModel(object):
 
     def __init__(self):
         self._alipay_store_id = None
+        self._bkagent_req_info = None
         self._body = None
         self._business_params = None
         self._buyer_id = None
         self._buyer_logon_id = None
+        self._buyer_open_id = None
         self._disable_pay_channels = None
         self._discountable_amount = None
         self._enable_pay_channels = None
@@ -56,6 +59,16 @@ class AlipayTradeCreateModel(object):
     def alipay_store_id(self, value):
         self._alipay_store_id = value
     @property
+    def bkagent_req_info(self):
+        return self._bkagent_req_info
+
+    @bkagent_req_info.setter
+    def bkagent_req_info(self, value):
+        if isinstance(value, BkAgentReqInfo):
+            self._bkagent_req_info = value
+        else:
+            self._bkagent_req_info = BkAgentReqInfo.from_alipay_dict(value)
+    @property
     def body(self):
         return self._body
 
@@ -87,6 +100,13 @@ class AlipayTradeCreateModel(object):
     def buyer_logon_id(self, value):
         self._buyer_logon_id = value
     @property
+    def buyer_open_id(self):
+        return self._buyer_open_id
+
+    @buyer_open_id.setter
+    def buyer_open_id(self, value):
+        self._buyer_open_id = value
+    @property
     def disable_pay_channels(self):
         return self._disable_pay_channels
 
@@ -300,6 +320,11 @@ class AlipayTradeCreateModel(object):
                 params['alipay_store_id'] = self.alipay_store_id.to_alipay_dict()
             else:
                 params['alipay_store_id'] = self.alipay_store_id
+        if self.bkagent_req_info:
+            if hasattr(self.bkagent_req_info, 'to_alipay_dict'):
+                params['bkagent_req_info'] = self.bkagent_req_info.to_alipay_dict()
+            else:
+                params['bkagent_req_info'] = self.bkagent_req_info
         if self.body:
             if hasattr(self.body, 'to_alipay_dict'):
                 params['body'] = self.body.to_alipay_dict()
@@ -320,6 +345,11 @@ class AlipayTradeCreateModel(object):
                 params['buyer_logon_id'] = self.buyer_logon_id.to_alipay_dict()
             else:
                 params['buyer_logon_id'] = self.buyer_logon_id
+        if self.buyer_open_id:
+            if hasattr(self.buyer_open_id, 'to_alipay_dict'):
+                params['buyer_open_id'] = self.buyer_open_id.to_alipay_dict()
+            else:
+                params['buyer_open_id'] = self.buyer_open_id
         if self.disable_pay_channels:
             if hasattr(self.disable_pay_channels, 'to_alipay_dict'):
                 params['disable_pay_channels'] = self.disable_pay_channels.to_alipay_dict()
@@ -464,6 +494,8 @@ class AlipayTradeCreateModel(object):
         o = AlipayTradeCreateModel()
         if 'alipay_store_id' in d:
             o.alipay_store_id = d['alipay_store_id']
+        if 'bkagent_req_info' in d:
+            o.bkagent_req_info = d['bkagent_req_info']
         if 'body' in d:
             o.body = d['body']
         if 'business_params' in d:
@@ -472,6 +504,8 @@ class AlipayTradeCreateModel(object):
             o.buyer_id = d['buyer_id']
         if 'buyer_logon_id' in d:
             o.buyer_logon_id = d['buyer_logon_id']
+        if 'buyer_open_id' in d:
+            o.buyer_open_id = d['buyer_open_id']
         if 'disable_pay_channels' in d:
             o.disable_pay_channels = d['disable_pay_channels']
         if 'discountable_amount' in d:
