@@ -9,6 +9,7 @@ class TransportAuthStatusData(object):
 
     def __init__(self):
         self._auth_status = None
+        self._open_id = None
         self._user_id = None
 
     @property
@@ -19,6 +20,13 @@ class TransportAuthStatusData(object):
     def auth_status(self, value):
         self._auth_status = value
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def user_id(self):
         return self._user_id
 
@@ -34,6 +42,11 @@ class TransportAuthStatusData(object):
                 params['auth_status'] = self.auth_status.to_alipay_dict()
             else:
                 params['auth_status'] = self.auth_status
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.user_id:
             if hasattr(self.user_id, 'to_alipay_dict'):
                 params['user_id'] = self.user_id.to_alipay_dict()
@@ -48,6 +61,8 @@ class TransportAuthStatusData(object):
         o = TransportAuthStatusData()
         if 'auth_status' in d:
             o.auth_status = d['auth_status']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'user_id' in d:
             o.user_id = d['user_id']
         return o
