@@ -3,6 +3,8 @@
 import json
 
 from alipay.aop.api.response.AlipayResponse import AlipayResponse
+from alipay.aop.api.domain.BkAgentRespInfo import BkAgentRespInfo
+from alipay.aop.api.domain.ChargeInfo import ChargeInfo
 from alipay.aop.api.domain.EnterprisePayInfo import EnterprisePayInfo
 from alipay.aop.api.domain.TradeFundBill import TradeFundBill
 from alipay.aop.api.domain.HbFqPayInfo import HbFqPayInfo
@@ -17,14 +19,17 @@ class AlipayTradeQueryResponse(AlipayResponse):
         self._alipay_store_id = None
         self._alipay_sub_merchant_id = None
         self._auth_trade_pay_mode = None
+        self._bkagent_resp_info = None
         self._body = None
         self._buyer_logon_id = None
+        self._buyer_open_id = None
         self._buyer_pay_amount = None
         self._buyer_user_id = None
         self._buyer_user_name = None
         self._buyer_user_type = None
         self._charge_amount = None
         self._charge_flags = None
+        self._charge_info_list = None
         self._credit_biz_order_id = None
         self._credit_pay_mode = None
         self._discount_amount = None
@@ -86,6 +91,16 @@ class AlipayTradeQueryResponse(AlipayResponse):
     def auth_trade_pay_mode(self, value):
         self._auth_trade_pay_mode = value
     @property
+    def bkagent_resp_info(self):
+        return self._bkagent_resp_info
+
+    @bkagent_resp_info.setter
+    def bkagent_resp_info(self, value):
+        if isinstance(value, BkAgentRespInfo):
+            self._bkagent_resp_info = value
+        else:
+            self._bkagent_resp_info = BkAgentRespInfo.from_alipay_dict(value)
+    @property
     def body(self):
         return self._body
 
@@ -100,6 +115,13 @@ class AlipayTradeQueryResponse(AlipayResponse):
     def buyer_logon_id(self, value):
         self._buyer_logon_id = value
     @property
+    def buyer_open_id(self):
+        return self._buyer_open_id
+
+    @buyer_open_id.setter
+    def buyer_open_id(self, value):
+        self._buyer_open_id = value
+    @property
     def buyer_pay_amount(self):
         return self._buyer_pay_amount
 
@@ -142,6 +164,19 @@ class AlipayTradeQueryResponse(AlipayResponse):
     def charge_flags(self, value):
         self._charge_flags = value
     @property
+    def charge_info_list(self):
+        return self._charge_info_list
+
+    @charge_info_list.setter
+    def charge_info_list(self, value):
+        if isinstance(value, list):
+            self._charge_info_list = list()
+            for i in value:
+                if isinstance(i, ChargeInfo):
+                    self._charge_info_list.append(i)
+                else:
+                    self._charge_info_list.append(ChargeInfo.from_alipay_dict(i))
+    @property
     def credit_biz_order_id(self):
         return self._credit_biz_order_id
 
@@ -437,10 +472,14 @@ class AlipayTradeQueryResponse(AlipayResponse):
             self.alipay_sub_merchant_id = response['alipay_sub_merchant_id']
         if 'auth_trade_pay_mode' in response:
             self.auth_trade_pay_mode = response['auth_trade_pay_mode']
+        if 'bkagent_resp_info' in response:
+            self.bkagent_resp_info = response['bkagent_resp_info']
         if 'body' in response:
             self.body = response['body']
         if 'buyer_logon_id' in response:
             self.buyer_logon_id = response['buyer_logon_id']
+        if 'buyer_open_id' in response:
+            self.buyer_open_id = response['buyer_open_id']
         if 'buyer_pay_amount' in response:
             self.buyer_pay_amount = response['buyer_pay_amount']
         if 'buyer_user_id' in response:
@@ -453,6 +492,8 @@ class AlipayTradeQueryResponse(AlipayResponse):
             self.charge_amount = response['charge_amount']
         if 'charge_flags' in response:
             self.charge_flags = response['charge_flags']
+        if 'charge_info_list' in response:
+            self.charge_info_list = response['charge_info_list']
         if 'credit_biz_order_id' in response:
             self.credit_biz_order_id = response['credit_biz_order_id']
         if 'credit_pay_mode' in response:
